@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: v_cback.h 2238 2007-10-07 19:14:55Z mbarbon $
-// Copyright:   (c) 2000-2007 Mattia Barbon
+// RCS-ID:      $Id: v_cback.h 3402 2012-10-01 11:18:15Z mdootson $
+// Copyright:   (c) 2000-2007, 2009 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -37,7 +37,7 @@ private:
 #ifdef MULTIPLICITY
     #undef register
     #define register
-    pTHX;
+    pTHXx;
     #undef register
 #endif
 };
@@ -56,6 +56,8 @@ public:
     SV* CallCallback( pTHX_ I32 flags, const char* argtypes,
                       va_list& arglist ) const;
     CV* GetMethod() const { return m_method; }
+
+    bool IsOk() const { return GetSelf() && m_package; }
 public:
     const char* m_package;
     HV* m_stash;
@@ -204,6 +206,36 @@ inline wxPliVirtualCallback::wxPliVirtualCallback( const char* package )
 #define DEC_V_CBACK_WXFSFILEP__WXFILESYSTEM_WXSTRING( METHOD ) \
   wxFSFile* METHOD( wxFileSystem&, const wxString& )
 
+#define DEC_V_CBACK_VOID__WXLOGLEVEL_WXSTRING_WXLOGRECORDINFO( METHOD ) \
+  void METHOD( wxLogLevel, const wxString&, const wxLogRecordInfo& )
+
+#define DEF_V_CBACK_VOID__WXLOGLEVEL_WXSTRING_WXLOGRECORDINFO( CLASS, BASE, METHOD ) \
+  void CLASS::METHOD( wxLogLevel p1, const wxString& p2, const wxLogRecordInfo& p3 ) \
+  {                                                                           \
+    dTHX;                                                                     \
+    if( wxPliVirtualCallback_FindCallback( aTHX_ &m_callback, #METHOD ) )     \
+    {                                                                         \
+        wxPliVirtualCallback_CallCallback( aTHX_ &m_callback, G_VOID,         \
+                                           "iPq", int(p1), &p2, &p3, "Wx::LogRecordInfo" ); \
+    }                                                                         \
+    BASE::METHOD( p1, p2, p3 );                                               \
+  }
+
+#define DEC_V_CBACK_VOID__WXLOGLEVEL_WXSTRING( METHOD ) \
+  void METHOD( wxLogLevel, const wxString& )
+
+#define DEF_V_CBACK_VOID__WXLOGLEVEL_WXSTRING( CLASS, BASE, METHOD ) \
+  void CLASS::METHOD( wxLogLevel p1, const wxString& p2) \
+  {                                                                           \
+    dTHX;                                                                     \
+    if( wxPliVirtualCallback_FindCallback( aTHX_ &m_callback, #METHOD ) )     \
+    {                                                                         \
+        wxPliVirtualCallback_CallCallback( aTHX_ &m_callback, G_VOID,         \
+                                           "iP", int(p1), &p2); \
+    }                                                                         \
+    BASE::METHOD( p1, p2 );                                               \
+  }
+
 #define DEC_V_CBACK_VOID__WXLOGLEVEL_CWXCHARP_TIMET( METHOD ) \
   void METHOD( wxLogLevel, const wxChar*, time_t )
 
